@@ -9,6 +9,7 @@
 """
 from pymongo import MongoClient
 from pycarol import ApiKeyAuth, Carol, Staging
+from pycarol.bigquery import BQ
 import pandas as pd
 import sys
 import os
@@ -59,3 +60,26 @@ def enviar_para_carol(**argumentos):
         resultado['descricao'] = 'Erro ao enviar para a Carol.' + str(erro) + ' na linha ' + str(exc_tb.tb_lineno) + ' da função: ' + __name__
     finally:
       return resultado
+
+
+def consultar_query_carol_bq(**argumentos):
+  resultado = {'status':False,'descricao':'Erro ao consultar na Carol','dados':{},'stack':''}
+  try:
+    carol = Carol(domain=argumentos.get('TENANT_NAME',''),
+      app_name=argumentos.get('APP_NAME',''),
+      auth=ApiKeyAuth(api_key=argumentos.get('X_AUTH_KEY','')),
+      connector_id=argumentos.get('CONNECTOR',''),
+      organization=argumentos.get('ORGANIZATION','')
+      )
+    bq = BQ(carol)
+    df = bq.query(argumentos.get('query',''), return_dataframe=True)
+    resultado['status'] = True
+    resultado['descricao'] = 'Sucesso ao consultar dados'
+    resultado['dados'] = df
+  except Exception as erro:
+          exc_type, exc_obj, exc_tb = sys.exc_info()
+          resultado['status'] = False
+          resultado['descricao'] = 'Erro ao enviar para a Carol.'
+          resultado['stack'] = 'Erro:' + str(erro) + ' na linha ' + str(exc_tb.tb_lineno) + ' da função: ' + __name__
+  finally:
+        return resultado
